import unittest
from ..preprocess.parser import *


class TestPreprocessMethods(unittest.TestCase):

    def __init__(self, methodName):
        super().__init__(methodName)
        self.benepar_en_parser = AtmanParser(UnderlyingModel.BENEPAR,
                                             Language.EN)
        self.benepar_zh_parser = AtmanParser(UnderlyingModel.BENEPAR,
                                             Language.ZH)
        self.corenlp_en_parser = AtmanParser(UnderlyingModel.CORE_NLP,
                                             Language.EN)
        self.corenlp_zh_parser = AtmanParser(UnderlyingModel.CORE_NLP,
                                             Language.ZH)



    def test_dump_and_load(self):
        od = OrderedDict()
        text='{"title": "Comparing the efficacy of sodium valproate and levetiracetam following initial lorazepam in elderly patients with generalized convulsive status epilepticus (GCSE): A prospective randomized controlled pilot study", "authors": "Devavrat Nenea, Ravindranadh Chowdary Mundlamuria, Parthasarathy Satishchandraa, Parthipulli Vasuki Prathyushac, Madhu Nagappaa, Parayil Sankaran Bindua, Kenchaiah Raghavendraa, Jitender Sainib, Rose Dawn Bharathb, Kandavel Thennarasuc, Arun B. Talya, Sanjib Sinhaa,\\u204e", "Affiliation": "a Department of Neurology, National Institute of Mental Health and NeuroSciences (NIMHANS), Bangalore, India\\nb Department of Neuroimaging and Interventions Radiology, National Institute of Mental Health and NeuroSciences (NIMHANS), Bangalore, India\\nc Department of Biostatistics, National Institute of Mental Health and NeuroSciences (NIMHANS), Bangalore, India", "keywords": "Keywords:\\nElderly seizures\\nGeneralised convulsive status epilepticus\\n(GCSE)\\nLevetiracetam (LEV)\\nSodium valproate (SVP)\\nStatus epilepticus (SE)\\nTreatment of SE", "abstract": "A B S T R A C T\\nPurpose: This randomized control study was conducted to compare the efficacy of sodium valproate (SVP) and levetiracetam (LEV) following initial intravenous lorazepam in elderly patients (age: > 60years) with generalized convulsive status epilepticus (GCSE) and to identify predictors of poor seizure control.\\nMethods: A total of 118 patients (mean age: 67.5 \\u00b1 7.5 years, M:F = 1.6:1), who had presented with GCSE were randomized into the SVP or LEV treatment arms. All patients received initial intravenous lorazepam (0.1 mg/kg) followed by one of the two antiepileptic drugs (AEDs), parenteral SVP (20\\u201325 mg/kg) or LEV (20\\u201325 mg/kg). Those who failed to achieve control with the initial AED, were crossed over to receive the other AED. One-hundred patients (SVP = 50; LEV = 50) completed the study. \\nResults: SE could be controlled with lorazepam and one of the AEDs (SVP or LEV) in 71.18% (84/118). Intention-to-treat analysis showed that the two groups did not differ significantly in terms of seizure control [SVP: 41/60 (68.3%); LEV: 43/58 (74.1%), p = 0.486]. Of 100 patients who completed the study, seizure control was achieved in 38/50(76%) in the SVP and 43/50(86%) in the LEV group (p = 0.202). After crossing over to the second AED, SE could be controlled in an additional in 50% (6/12) in SVP (+LEV) group and in 14.3% (1/7) in LEV (+SVP) group. Overall, after the second AED, seizure control was achieved in 77.1% (91/118). Higher STESS was associated with poor therapeutic response (p = 0.049). \\nConclusions: The efficacy of SVP and LEV following initial lorazepam in controlling GCSE in elderly population was comparable, hence the choice of AED could be individualized.", "introduction": "Introduction\\nStatus epilepticus (SE) is a neurological emergency with severe consequences especially in elderly with other co-morbidities [1]. SE has a bimodal distribution with the highest incidence in children < 1 year and adults older than 60 years [2,3]. Generalized convulsive status epilepticus (GCSE) is the most common and life-threatening type of SE with an overall mortality of around 20%. Mortality is higher in the elderly being 30%\\u201370% [4,5].\\nThere are no randomized control trials (RCTs) in elderly patients with GCSE and the current guidelines for treatment are derived from the studies carried out in the younger population. Benzodiazepines are used as first-line agents for treatment of SE because they are effective for most of the seizure types and are fast acting. Lorazepam is more effective than diazepam in terminating SE [6]. Sodium valproate (SVP) has been a potential choice of anti-epileptic drug (AED) in the treatment of SE in the elderly because of low risk of hypotension, respiratory depression and sedation. Likewise, levetiracetam (LEV) has a favorable pharmacokinetic profile, fewer drug interactions and is well tolerated by critically-ill elderly subjects [7]. \\nThis RCT aimed to ascertain and compare the efficacy of parenteral SVP and LEV following initial lorazepam in elderly patients with GCSE as well as to analyze the predictors for poor seizure control.", "Materials and methods": "2. Materials and methods\\n  This prospective, single blinded, randomized controlled, singlecentre study was carried out at a tertiary care University teaching hospital in south India over a period of one and half years. Elderly patients (age > 60 years) with GCSE were recruited by a neurology resident (DN) under close supervision of an experienced investigators with special interest in epilepsy (SS, PSC, RC). Consent for the study was obtained from patients\' relative/surrogate. The exclusion criteria were i) lack of consent, ii) patients presenting primarily with nonconvulsive SE, iii) hepatic or renal failure, cardiac disease (based on clinical judgment, available lab reports, ECG at presentation), iv) history of allergy to the study drugs, v) administration of any parenteral treatment with the study drug/any other drug for this episode of SE before being referred to our centre for management of SE. The Institute Ethics Committee (IEC) approved the study to obtain written informed consent for participation in the study from a family member or accompanying person (surrogate), since patients were not competent to give informed consent. The study was a registered as a clinical trial (CTRI/2016/05/006932).\\n2.1. Definitions\\n  GCSE: presence of continuous generalized convulsive seizure activity for more than five minutes or two or more sequential seizures without full recovery of consciousness in between the seizures [8].\\n  Control of SE: a) No recurrence of seizures after half an hour of infusion of study drugs and with substantial clinical improvement in level of sensorium in the next 24 h; and b) If sensorium did not improve substantially but EEG changes were not suggestive of NCSE. \\n  Uncontrolled SE: a) recurrence of seizures after half an hour of completion of infusion up to 24 h; and b) lack of substantial clinical improvement in sensorium and with EEG changes suggestive of NCSE. \\n  Acute symptomatic SE: SE that is caused by acute symptomatic causes like neuro-infection, metabolic disturbances, stroke, tumor, hydrocephalus, and trauma [8]. \\n  Remote symptomatic SE: SE that is caused by remote symptomatic causes/ sequelae of previous brain insults like old stroke, calcified granuloma, gliosis, and low-grade tumor [8].\\n  Cryptogenic SE: underlying cause of SE is as yet unknown [8,9].\\n  Pre-existing epilepsy: Two or more unprovoked epileptic seizures that occurred more than four weeks prior to the onset of SE [10] \\n  De-novo/new-onset SE: Patients who present first time in life with SE without pre-existing epilepsy [10].\\n2.2. Initial management and randomization\\n  At initial presentation to the emergency services, pulse rate, blood pressure, respiratory rate, peripheral capillary oxygen saturation (SpO2), and random blood sugar levels were measured and steps were taken to stabilize the airway, breathing and circulation of all the enrolled patients. A quick clinical history regarding seizures was obtained and clinical examination including assessment of Glasgow Coma Scale (GCS) and Status Epilepticus Severity Score (STESS) was performed. All the patients with GCSE received intravenous lorazepam (0.1 mg/kg; 4\\u20136 mg) within five minutes of arrival to the emergency services. Subjects fulfilling the inclusion criteria were randomized using computer generated random numbers into two treatment arms viz SVP or LEV.\\n  Out of 128 patients (M:F = 79:49) who were screened during the study period, 10 patients did not fulfill the inclusion criteria and were excluded (M:F = 6:4; age:68 \\u00b1 6.9 years). Out of the 118 patients, 14 patients were excluded after randomization. The reasons for exclusion were symptomatic SE due to hyponatremia (n = 4) and non-ketotic hyperglycemia (n = 4), cluster seizures, that were incorrectly diagnosed as GCSE (n = 3), refusal to continue to be a part of the study (n = 2), complete heart block (n = 1), and four patients were incorrectly assigned to SVP arm instead of LEV. Thus 100 patients, including 50 each in the SVP and LEV arms, were analyzed for primary outcome of control of SE. All the 118 patients who were randomized (LEV: 58; SVP: 60) were included in Intention to Treat (ITT) analysis (Fig. 1).\\n2.3. First line AED\\n  Intravenous lorazepam was followed by administration of intravenous SVP or LEV based on the treatment arm to which the patient was randomized. This was done within 10 min of arrival in the emergency services. SVP (20\\u201325 mg/kg IV in 100 ml saline) was infused over 15\\u201320 min and this was followed by maintenance dose (20\\u201325 mg/kg/ day in two divided doses). LEV (20\\u201325 mg/kg IV) was infused over 15 min followed by maintenance dose (20\\u201325 mg/kg/day in three divided doses).\\n2.4. Second line AED\\n  Patients with uncontrolled SE were switched over as follows: \\n  a) Uncontrolled SE after SVP: Received LEV in the above-mentioned dosages. \\n  b) Uncontrolled SE after LEV: Received SVP in the above-mentioned dosages.\\n2.5. Investigations\\n  Routine investigation including complete hemogram, serum glucose, electrolytes, and hepatic and renal function tests were carried out in all. Imaging of brain (CT/MRI), scalp electroencephalography (EEG) and wherever indicated, lumbar puncture and analysis of cerebrospinal fluid, were performed to determine the etiology.\\n2.6. Discharge and follow up\\n  Patients were discharged after 24\\u201348 h of seizure-free period in stable condition. Glasgow Outcome Scale (GOS) and modified Rankin Scale (mRS) were assessed at the time of discharge. The patients were followed-up after one month personally or by telephonic interview. Information regarding seizure control, recurrence of SE, AED compliance, morbidity in terms of activities of daily living, GOS and mRS and mortality was gathered.\\n2.7. Statistical analysis\\n  Statistical analysis was performed using the statistical software IBM SPSS Statistics 22.0 (2013, IBM Corp, Armonk, NY) for Windows. Normality of the variables was tested using the Kolmogorov-Smirnov test. If normally distributed, group comparisons for quantitative parameters were calculated using the t-test; otherwise the Mann-Whitney U test was used. Pearson\\u2019s Chi-Square test was used to find the association among qualitative parameters. Level of significance was fixed at 5%. Patients who were excluded after randomization were analyzed using ITT due to dropouts in the study following randomization, with last observation carried forward for follow-up grades and primary outcome. Logistic regression analysis was carried out to identify the predictors of the control of SE and mortality.\\n", "result": "3. Results\\n  The clinical, EEG and imaging features of 118 patients recruited in the two treatment arms summarized in Table 1 and the etiology of SE was provided in Supplementary Table 1. Most of the baseline characteristics of the two groups were similar except that patients in the SVP arm had higher frequency of alcohol abuse (p = 0.039) and tachycardia (p = 0.03) compared to those in the LEV arm. \\n3.1. SE control with first line AED\\n  In this cohort (n = 100), control of SE was achieved in 81% [SVP arm: 38/50 (76%), LEV arm: 43/50 (86%), p = 0.202]. ITT analysis (n = 118) showed that SVP following lorazepam led to seizure control in 68.3% (41/60), while LEV following lorazepam led to seizure control in 74.1% (43/58). However, this difference was not statistically significant (p = 0.486) (Table 2).\\n3.2. SE control with second line AED\\n  LEV could control seizures in 50% (6/12) of patients who had uncontrolled SE with lorazepam plus SVP. SVP could control seizures in 14.2% (1/7) of patients who had uncontrolled SE after lorazepam plus LEV. But the difference was not statistically significant (p = 0.173). Patients who had uncontrolled SE after the administration of second line AED ceased to be a part of the study. They were provided treatment as per recommended practice guidelines.\\n3.3. Follow up observations\\n  One month follow-up was available for 113/118 patients. Functional outcome measures (GOS & mRS) were similar in both groups. Thirty-day mortality was 20.3% (23/113) and it was comparable in both the groups [SVP: 13 (22.4%), LEV: 10 (18.2%); p = 0.93]. Patients with de-novo SE had higher mortality as compared to patients with pre-existing epilepsy however it was not statistically significant [de-novo: 16/71 (22.5%), pre-existing epilepsy: 7/47 (14.9%), p = 0.164]. The causes of death were: a) recurrent SE: 6 (26.1%), b) pneumonia and respiratory failure: 5 (21.7%), c) sudden cardiac arrest: 4 (17.4%), d) multi-organ dysfunction due to sepsis: 4 (17.4%), e) raised intracranial pressure due to intracranial haemorrhage: 2 (8.7%), f) advanced malignancy: 1 (4.3%), and g) hypovolemic shock: 1 (4.3%). Based on the preliminary analysis the following observations were made.\\n3.4 Predictors of SE control\\n  SpO2 at admission < 90% was associated with poor therapeutic response (p = 0.049) (Table 3). Stepwise logistic regression was carried out to find the predictors of the control of SE age, first line AED, GCS at admission, STESS, SpO2, random blood sugar, systolic blood pressure and past history of stroke as predictors. The final model after stepwise regression resulted with STESS [Odds ratio (OR) = 1.92, p = 0.049] as a definite predictor. Lower systolic blood pressure showed only a trend for poor outcome, but no statistical significance as the p value was closer to 0.05. Sub-group analysis of delayed arrival to hospital (2\\u20134 h, 4\\u20135 h, 5\\u20137 h, 7\\u201324 h; p = 0.358) and those with acute symptomatic aetiology vs rest (p = 0.712) did not achieve statistical significance. \\n3.5. Predictors of mortality\\n  Female gender (p = 0.024), SpO2 at admission < 90% (p < 0.001), acute symptomatic SE (p = 0.005), uncontrolled SE (p = 0.05), lower GCS at admission and discharge (p < 0.001) as well as poor mRS (p < 0.001) and poor GOS (p < 0.001) at discharge were associated with higher mortality (Table 4).\\n3.6. Adverse effects of AEDs\\n  There were no adverse events noted during administration of either of the study drugs. One patient had evidence of hepatic dysfunction on day 3 in the SVP group.", "discussion": "4. Discussion\\n  Since there are no RCTs and standard guideline/protocol for management of SE in elderly patients, we tend to extrapolate the recommendations for the management of SE in adults. In elderly patients, alterations in metabolism substantially influence pharmaco-kinetics and dynamics of the administered drugs often requiring treatment modifications. Mortality among elderly patients with SE is the highest amongst all the age groups necessitating us to focus more on the management aspect. Hence, this study was conducted to compare efficacy of commonly used AEDs (SVA vs LEV) in controlling GCSE in elderly patients along with initial lorazepam. We adopted this protocol of assessing the combined effect of lorazepam and one of the study drugs because of following practical reasons. A) Experimental evidence supports early administration of a combination of medications with multiple mechanisms of action [11]. B) Most patients presented to our center after a minimum duration of 2\\u20135 h after the onset of GCSE. After 30 min of ongoing seizure, benzodiazepine receptors may be down regulated and hence the therapeutic potential of lorazepam is expected to be reduced [12]. C) After lorazepam monotherapy, about one-third may still have uncontrolled SE, which is undesirable. D) A previous study among adults with GCSE from our center demonstrated the safety and efficacy of administering benzodiazepine followed by an AED [14]; moreover one of the treatment arms in the landmark study by Treiman et al received benzodiazepine and phenytoin [13]. There is an experimental evidence for synergistic action of lorazepam and SVA in controlling SE [11]. E) Most benzodiazepines have a short half-life and a likelihood of developing tolerance; hence long-acting AEDs may be administered to prevent seizure recurrence. Though need for combination therapy has been emphasized in some reviews, it is not routinely recommended as an ideal protocol [12,15,16]. \\n  This is the first RCT in elderly patients with GCSE. After screening 128 elderly patients with GCSE, 118 patients were randomized to one of two study groups and 100 patients completed the study. In this cohort (n = 100), control of SE was achieved without any statistically significant difference between the groups (SVP-76%, LEV-86%, p = 0.202). ITT analysis (n = 118) did not reveal that one group is superior to the other (SVP: 68.3%; LEV: 74.1%, p = 0.48). SE could be controlled with lorazepam and one of AEDs (SVP or LEV) in 71.18%. After crossing over to the second AED, SE could be controlled in: SVP (+LEV) group in 50%; LEV (+SVP) group in 14.3%. Overall, after adding the second AED, SE was controlled in 77.1%. Fattouch et al found that the efficacy of LEV in elderly patients with SE (n = 9) was 77.7%, that was similar to the current study [17]. \\n  Treiman et al demonstrated that lorazepam alone controlled SE in 64.9% patients, which may suggest that addition of a long-acting AED has minimal added benefit. However, diazepam plus phenytoin could control SE in only 55.8% which is lower than the lorazepam monotherapy group (64.9%). Here a 60-minute seizure-free period was used for analysis as compared to the current study where control of SE was defined as improvement for 24 h. Hence direct comparison with the present study may not be possible [13]. In addition, though both the studies were randomized, inclusion of the all adult patients with subtle and overt SE, as well as treated and untreated patients in the study by Treiman et al, makes comparison with the current study less meaningful. Navarro et al conducted a pre-hospital double-blind, randomized, placebo-controlled, superiority trial to determine efficacy of addition of LEV to clonazepam among study participants aged 55 \\u00b1 18 years. Convulsions stopped in 74% after addition of LEV to clonazepam as compared to our study (86%) [18]. This difference may be due to the fact that 15 min endpoint of seizure control considered in their study; drug-drug interaction, and synergistic effect of lorazepam in our study may also play a role. However, study by Navarro et al., did not find additional benefit of combination therapy of LEV and clonazepam compared with clonazepam alone. The benefit of synergistically acting drugs with different mechanisms of action viz diazepam, ketamine and valproate were demonstrated in an experimental study [11].\\n  In this study, overall seizure control was achieved in 77.1% of patients after switching the treatment arms. This might be due to combined action of lorazepam and the study drug, each having different mechanism of action, synergism between drugs, delayed action or due to drug-drug interactions leading to increased free levels of one drug among others. This is an encouraging observation and might suggest that patients could be administered multiple AEDs, provided their vitals parameters (SpO2, blood pressure) are maintained especially in resource-limited settings. LEV is slightly more effective than SVP (74.1% vs 68.3%; p = 0.48) following initial lorazepam. Similar observations were made in another study from this centre carried out among adults with CSE, wherein the efficacy of phenytoin, valproate and levetiracetam following lorazepam was 68%, 68% and 78% (p = 0.44) respectively [14]. Probably, a larger cohort is required to ascertain these findings. The results of our study are comparable to some studies but differ from some other studies, though direct comparison might not be correct due to different methodology, AEDs and its dosages, patient population, definition of SE and controlled and not controlled. \\n  Patients with SE in developing world arrive late in hospital and this is considered to be one of the factors for higher mortality. In a study done by Kalita et al, the median duration of SE was 20.65 \\u00b1 22.07 h [19]. In another study from this centre by Sinha et al [20], the mean duration of SE was 25.5 h, which was much higher as compared to the present study done five years later (5.5 h), and moreover the cohort was different in these two studies. This may be due to better transport facilities and improved awareness. But, it is still longer when compared to developed countries where studies report that 39% patients reach the hospital within 30 min of SE.\\n  It was observed that lower SpO2 at admission (< 90%) was significantly associated with poor response to first line AED (p = 0.049). After stepwise regression analysis higher STESS was associated with poor response to first line AED (OR = 1.92, p = 0.049). A study by Goyal et al showed that higher STESS had significant correlation with poor neurological outcome at discharge (p = 0.0001), and lack of response to treatment within one hour (p = 0.001) [21].\\n  It was also noted that in 23/113 patients who died in the present study, female gender (p = 0.024), SpO2 at admission < 90% (p < 0.001), acute symptomatic SE (p = 0.005), uncontrolled SE (p = 0.05), lower GCS at admission and discharge (p < 0.001), as well as poor mRS (p < 0.001) and poor GOS (p < 0.001) at discharge were significantly more common. In a study done by Yoshimura et al, univariate analysis showed that poor outcome was significantly associated with de-novo epilepsy (p = 0.003) [22]. Similarly, Sutter et al concluded that patients with history of seizures had better outcome compared to de-novo SE [23]. But in our cohort, those with de-novo SE showed a trend towards higher mortality, which may be due to the small sample size. Yoshimura et al reported that poor outcome was associated with acute symptomatic (p = 0.003) and remote symptomatic (p = 0.02) compared with cryptogenic SE [22]. In our study, only acute symptomatic SE was associated with poor outcome, which is in concordance with few reports [4,24]. Treiman et al reported that the 30-day mortality was 27% and unresponsiveness to the first AED was the most significant risk factor [13].\\n  Sutter et al concluded that acute symptomatic SE is associated with a poorer outcome, which is consistent with our observations [23]. They found inconsistent evidence to establish a link between gender and SE outcome, which may be due to inconsistency of data obtained from population-based studies and systematic reviews [23]. In the same review, it was noted that uncontrolled or refractory SE was also associated with higher mortality, an observation consistent with the present study.\\n  Thirty-day mortality was noted in 20.3% without any significant difference between the two treatment arms (SVP: 22.4%, LEV: 10%; p = 0.19). Chin et al reported a short-term mortality up to 22% in patients with CSE, being the highest in the elderly [2]. The overall mortality observed by Sung and Chu was 35% [25]. The higher mortality in their study may be due to the fact that majority had acutesymptomatic SE in contrast to remote symptomatic SE in our study. Sinha et al reported a lower mortality of 7.9% in elderly patients with new onset SE and cluster seizures, which might be attributed to higher frequency of treatable etiologies and inclusion of patients with cluster seizures in their cohort [20].\\n  The limitations of this study include: a) small sample size; b) single blinding; c) serum AED levels were not performed which is important before deciding whether or not the drug is efficacious as pharmacodynamics and kinetics may vary between individuals; d) continuous EEG monitoring was not done; e) dosage used (20\\u201325 mg/kg) was less compared to current prevailing knowledge [26] and f) study design: use of combination of lorazepam and another AED rather than lorazepam alone and then another AED, if seizures remained uncontrolled. Despite sample size being small, it is the only and largest single center prospective, randomized, controlled study involving two AEDs among elderly subjects.\\n  ", "conclusion": "5. Conclusions\\n  Efficacy of SVP and LEV following initial lorazepam in controlling SE in elderly population was statistically not different; hence the choice of AED could be individualized. Higher STESS at admission was associated with poor seizure control. Thirty-day mortality was more common in patients with female gender, lower SpO2 at admission, acute symptomatic SE, uncontrolled SE, lower GCS at admission and poor mRS and GOS at discharge. Overall seizure control of 77.1% was achieved by administering upto two AEDs. This is particularly encouraging as seizure control could be achieved in majority without anaesthetic medication. Therefore, a clinician can choose any of the two parenteral AEDs following initial lorazepam in the management of elderly SE. Future studies could be planned to compare the efficacy of lorazepam alone vs combination treatment as first line treatment in SE.\\n ", "ethical approval": "Ethical approval\\n  \\u2018We confirm that we have read the Journal\\u2019s position on issues involved in ethical publication and affirm that this report is consistent with those guidelines.\\u2019", "Authors\\u2019 contributions": "Authors\\u2019 contributions\\n  Nene D: Patient recruitment and randomisation, data collection, data analysis, writing first draft, approved final manuscript, accountable for data accuracy and integrity. \\n  Mundlamuri RC: Study concept and design, study supervision, data collection, data analysis, critical revision of manuscript for important intellectual content, approved final manuscript, accountable for data accuracy and integrity. \\n  Satishchandra P: Study supervision, data collection, critical revision of manuscript for important intellectual content, approved final manuscript, accountable for data accuracy and integrity. \\n  Prathyusha PV: Data analysis and interpretation, contributed important intellectual content (statistics), approved final manuscript, accountable for data accuracy and integrity.\\n  Nagappa M: Data collection, critical revision of manuscript for important intellectual content, approved final manuscript, accountable for data accuracy and integrity.\\n  Bindu PS: Clinical data collection, draft revision, approved final manuscript, accountable for data accuracy and integrity. \\n  Raghavendra K: Clinical data collection, draft revision, approvedfinal manuscript, accountable for data accuracy and integrity\\n  Saini J: Analysis and interpretation of MRI data, draft revision, approved final manuscript, accountable for data accuracy and integrity.\\n  Bharath RD: Analysis and interpretation of MRI data, draft revision, approved final manuscript, accountable for data accuracy and integrity.\\n  Thennarasu K: Data analysis and statistics, contributed important intellectual content (statistics), approved final manuscript, accountable for data accuracy and integrity. \\n  Taly AB: Data interpretation, critical revision of manuscript for important intellectual content, approved final manuscript. \\n  S Sinha: Study concept and design, study supervision, data collection, data analysis, critical revision of manuscript for important intellectual content, approved final manuscript, accountable for data accuracy and integrity, and overall responsiblity", "Conflicts of interest": "Conflicts of interest\\nNil.", "funding": "Funding\\nNil.", "Acknowledgement": "Acknowledgement\\nWe sincerely acknowledge the patients who have participated in this study and their families for their kind co-operation.", "Appendix A. Supplementary data": "Appendix A. Supplementary data\\nSupplementary material related to this article can be found, in the online version, at doi:https://doi.org/10.1016/j.seizure.2019.01.015.", "footer": "\\u204e Corresponding author.\\n  E-mail addresses: doctordforu@gmail.com (D. Nene), drpsatishchandra@yahoo.com (P. Satishchandra), vasukiusha1987@gmail.com (P.V. Prathyusha), madhu_nagappa@yahoo.co.in (M. Nagappa), drpsbindu@yahoo.co.in (P.S. Bindu), raghoo2k@gmail.com (K. Raghavendra), jsaini76@gmail.com (J. Saini), drrosedawn@yahoo.com (R.D. Bharath), kthenna@gmail.com (K. Thennarasu), abtaly@yahoo.com (A.B. Taly), sanjib_sinha2004@yahoo.co.in (S. Sinha). \\n  https://doi.org/10.1016/j.seizure.2019.01.015\\n  Received 29 August 2018; Received in revised form 11 January 2019; Accepted 15 January 2019 1059-1311/ \\u00a9 2019 British Epilepsy Association. Published by Elsevier Ltd. All rights reserved."}'
        od = json.loads(text, object_pairs_hook=OrderedDict)
        doc =  self.benepar_en_parser.parse(od)
        print(doc.dumps())


if __name__ == '__main__':
    unittest.main()
